window.Gleam.initSearch([{"doc":"delay","title":"delay","content":"# Delay ⌚\n\nA dead simple data-structure for delaying side effects ⌚! Written in the excellent [gleam ✨](https://gleam.run/) language. Supporting both Erlang &amp; Javascript targets\n\n[![test](https://github.com/bwireman/delay/actions/workflows/test.yml/badge.svg)](https://github.com/bwireman/delay/actions/workflows/test.yml)\n[![commits](https://img.shields.io/github/last-commit/bwireman/delay)](https://github.com/bwireman/delay/commit/main)\n[![mit](https://img.shields.io/github/license/bwireman/delay?color=brightgreen)](https://github.com/bwireman/delay/blob/main/LICENSE)\n[![PRs Welcome](https://img.shields.io/badge/PRs-welcome-brightgreen)](http://makeapullrequest.com)\n[![0.2.0](https://img.shields.io/hexpm/v/delay?color=brightgreen&amp;style=flat)](https://hexdocs.pm/delay/index.html)\n[![gleam erlang](https://img.shields.io/badge/erlang%20%E2%98%8E%EF%B8%8F-red?style=flat&amp;label=gleam%20%E2%9C%A8)](https://gleam.run)\n[![downloads](https://img.shields.io/hexpm/dt/delay?color=brightgreen)](https://hex.pm/packages/delay/)\n[![gleam js](https://img.shields.io/badge/%20gleam%20%E2%9C%A8-js%20%F0%9F%8C%B8-yellow)](https://gleam.run/news/v0.16-gleam-compiles-to-javascript/)\n[![npm](https://img.shields.io/npm/dt/delay-gleam)](https://www.npmjs.com/package/delay-gleam)\n\n\n## Basic Usage\n\n```gleam\nimport gleam/io\n\nlet d = delay_effect(fn() {\n  io.println(&quot;Hello&quot;)\n  Ok(1)\n}) |&gt; delay.map(fn(x) {\n  io.println(&quot;World&quot;)\n  Ok(x + 1)\n})\n\nlet res = delay.run(d)\n// Hello\n// World\n// res = Ok(2)\n```\n\n## More info\n\nThe result of `delay_effect` is really just a first class function with a nice API wrapper. It isn&#39;t executed until put through one of `run/1`, `drain/1` or `fallthrough/1`. And can be called as many times as you want.\n\n```gleam\nlet d = delay_effect(fn() {\n  io.println(&quot;Hello&quot;)\n  Error(&quot;bummer&quot;)\n}) |&gt; delay.map(fn(x) {\n  io.println(&quot;World&quot;)\n  Ok(x + 1)\n})\n\nlet res = delay.run(d)\n// Hello\n// res = Error(&quot;bummer&quot;)\n```\n\nIf one of the functions in the chain fails, the rest will short circuit and the error will be returned.\n\nEffects can be retried as well via `retry/3`\n\n```gleam\n// using the same effect `d` from above\n\nlet res = delay.retry(d, 3, 200) |&gt; delay.run()\n// Hello\n// Hello\n// Hello\n// Hello\n// res = Error(&quot;bummer&quot;)\n```\n\n## Usage within Javascript 🌸 directly\nIf you want to use this library from javascript alone, but aren&#39;t ready to embrace gleam, you can install it from [npm](https://www.npmjs.com/package/delay-gleam)!\nYou will need a copy of Gleam&#39;s [JS prelude](https://github.com/gleam-lang/gleam/blob/v0.34.1/compiler-core/templates/prelude.mjs) as well. Docs can be found [here](https://hexdocs.pm/delay/index.html)\n\n```sh\nnpm i delay-gleam\n```\n\n```javascript\nimport { delay_effect, map, run } from &quot;delay-gleam&quot;\nimport { Ok, Error } from &quot;./prelude.mjs&quot;\n\nd = delay_effect(() =&gt; new Error(console.log(&quot;123&quot;)))\nd = map(d, (_) =&gt; new Ok(console.log(&quot;456&quot;)))\nrun(d)\n// 123\n```\n\n## FAQ\n\nDoesn&#39;t the concept of a delayed side effect kind of lose value in the world of actor model concurrency and zero shared memory?!\n\n&gt; A little\n\nThen why did you write this?\n\n&gt; For fun\n\nIs gleam ✨ actually excellent?\n\n&gt; So far\n","url":"index.html"},{"doc":"delay","title":"Delay","content":"pub opaque type Delay(val, error)\n\n\nSynonyms:\ndelay.Delay\ndelay Delay","url":"delay.html#Delay"},{"doc":"delay","title":"all","content":"pub fn all(effects: List(Delay(a, b))) -&gt; Bool\n run all effects in sequence and return True if all succeed\n note this will _always_ run _every_ effect\nSynonyms:\ndelay.all\ndelay all","url":"delay.html#all"},{"doc":"delay","title":"any","content":"pub fn any(effects: List(Delay(a, b))) -&gt; Bool\n run all effects in sequence and return True if any succeeds\n note this is different than `fallthrough/1` because it will _always_ run _every_ effect\nSynonyms:\ndelay.any\ndelay any","url":"delay.html#any"},{"doc":"delay","title":"delay_effect","content":"pub fn delay_effect(f: fn() -&gt; Result(a, b)) -&gt; Delay(a, b)\n store an effect to be run later\n if `f` returns an Error then chain will stop \nSynonyms:\ndelay.delay_effect\ndelay delay_effect","url":"delay.html#delay_effect"},{"doc":"delay","title":"drain","content":"pub fn drain(delayed: Delay(a, b)) -&gt; Nil\n run a delayed effect and throw away the result\n short-circuiting if any in the chain returns an Error\nSynonyms:\ndelay.drain\ndelay drain","url":"delay.html#drain"},{"doc":"delay","title":"every","content":"pub fn every(effects: List(Delay(a, b))) -&gt; List(Result(a, b))\n run every effect in sequence and get their results\nSynonyms:\ndelay.every\ndelay every","url":"delay.html#every"},{"doc":"delay","title":"fallthrough","content":"pub fn fallthrough(effects: List(Delay(a, b))) -&gt; Result(a, b)\n attempt multiple Delays until one returns an Ok\n unlike `any/1` this will short circuit on the first Ok\nSynonyms:\ndelay.fallthrough\ndelay fallthrough","url":"delay.html#fallthrough"},{"doc":"delay","title":"flat_map","content":"pub fn flat_map(\n  delayed: Delay(a, b),\n  f: fn(a) -&gt; Result(Delay(c, b), b),\n) -&gt; Delay(c, b)\n map and then flatten Delay\nSynonyms:\ndelay.flat_map\ndelay flat_map","url":"delay.html#flat_map"},{"doc":"delay","title":"flatten","content":"pub fn flatten(delayed: Delay(Delay(a, b), b)) -&gt; Delay(a, b)\n flatten nested Delay\nSynonyms:\ndelay.flatten\ndelay flatten","url":"delay.html#flatten"},{"doc":"delay","title":"map","content":"pub fn map(\n  delayed: Delay(a, b),\n  f: fn(a) -&gt; Result(c, b),\n) -&gt; Delay(c, b)\n chains an operation onto an existing delay to be run one then into the next\n if delayed has already error&#39;d then `f` will be ignored \nSynonyms:\ndelay.map\ndelay map","url":"delay.html#map"},{"doc":"delay","title":"repeat","content":"pub fn repeat(\n  delayed: Delay(a, b),\n  repitions: Int,\n) -&gt; List(Result(a, b))\n repeat a Delay and return the results in a list \nSynonyms:\ndelay.repeat\ndelay repeat","url":"delay.html#repeat"},{"doc":"delay","title":"retry","content":"pub fn retry(\n  delayed: Delay(a, b),\n  retries: Int,\n  delay: Int,\n) -&gt; Delay(a, b)\n returns a Delay that will be re-attempted `retries` times with `delay` ms in between\n NOTE: `delay` is ignored in JS\nSynonyms:\ndelay.retry\ndelay retry","url":"delay.html#retry"},{"doc":"delay","title":"retry_with_backoff","content":"pub fn retry_with_backoff(\n  delayed: Delay(a, b),\n  retries: Int,\n) -&gt; Delay(a, b)\n returns a Delay that will be re-attempted `retries` times with an increasing backoff delay\n NOTE: there is no backoff in JS\nSynonyms:\ndelay.retry_with_backoff\ndelay retry_with_backoff","url":"delay.html#retry_with_backoff"},{"doc":"delay","title":"run","content":"pub fn run(delayed: Delay(a, b)) -&gt; Result(a, b)\n run a delayed effect and get the result\n short-circuiting if any in the chain returns an Error\nSynonyms:\ndelay.run\ndelay run","url":"delay.html#run"},{"doc":"delay","title":"delay","content":"","url":"delay.html"}]);